#!/bin/bash

if [ -z "$1" ]
then
  echo "Error: No test specified"
  exit 1
fi

TEST="$1"
[[ "$TEST" =~ ^/ ]] || TEST="./$TEST"

OK=0
WARN=0
FAIL=0
LOG=$(basename $TEST).log
echo "Starting tests: $(date)"
$TEST | tee $LOG
echo "Finished: $(date)"
IFS='
'
while read line
do
  echo $line
  if [[ "$line" =~ ^pass ]]
  then
    OK=$((OK+1))
  elif [[ "$line" =~ "^failed as expected" ]]
  then
    ((WARN+=1))
  elif [[ "$line" =~ ^failed ]]
  then
    FAIL=$((FAIL+1))
  elif [[ "$line" =~ ^timeout ]]
  then
    ((WARN+=1))
  fi
done <$LOG
rm -f $LOG
echo "Tests took $SECONDS seconds"
echo "From $((OK+WARN+FAIL)) tests:"
echo " $OK passed"
echo " $FAIL failed"
echo " $WARN did not complete in time or failed (and was expected to fail)"
[ $FAIL = 0 ]


